@@ -1,5 +1,6 @@
 require "execjs/module"
 require "execjs/disabled_runtime"
+require "execjs/duktape_runtime"
 require "execjs/external_runtime"
 require "execjs/ruby_racer_runtime"
 require "execjs/ruby_rhino_runtime"
@@ -8,6 +9,8 @@ module ExecJS
   module Runtimes
     Disabled = DisabledRuntime.new
 
+    Duktape = DuktapeRuntime.new
+
     RubyRacer = RubyRacerRuntime.new
 
     RubyRhino = RubyRhinoRuntime.new
@@ -43,7 +46,7 @@ module ExecJS
     def self.autodetect
       from_environment || best_available ||
         raise(RuntimeUnavailable, "Could not find a JavaScript runtime. " +
-          "See https://github.com/sstephenson/execjs for a list of available runtimes.")
+          "See https://github.com/rails/execjs for a list of available runtimes.")
     end
 
     def self.best_available
@@ -52,15 +55,11 @@ module ExecJS
 
     def self.from_environment
       if name = ENV["EXECJS_RUNTIME"]
-        if runtime = const_get(name)
-          if runtime.available?
-            runtime if runtime.available?
-          else
-            raise RuntimeUnavailable, "#{runtime.name} runtime is not available on this system"
-          end
-        elsif !name.empty?
-          raise RuntimeUnavailable, "#{name} runtime is not defined"
-        end
+        raise RuntimeUnavailable, "#{name} runtime is not defined" unless const_defined?(name)
+        runtime = const_get(name)
+
+        raise RuntimeUnavailable, "#{runtime.name} runtime is not available on this system" unless runtime.available?
+        runtime
       end
     end
 
@@ -72,8 +71,9 @@ module ExecJS
       @runtimes ||= [
         RubyRacer,
         RubyRhino,
-        JavaScriptCore,
+        Duktape,
         Node,
+        JavaScriptCore,
         SpiderMonkey,
         JScript
       ]
