@@ -1,5 +1,5 @@
 (function(program, execJS) { execJS(program) })(function() {
-  return eval(#{encoded_source});
+  return eval(#{encode_source(source)});
 }, function(program) {
   #{json2_source}
   var output, print = function(string) {
@@ -13,10 +13,10 @@
       try {
         print(JSON.stringify(['ok', result]));
       } catch (err) {
-        print('["err"]');
+        print(JSON.stringify(['err', err.name + ': ' + err.message, err.stack]));
       }
     }
   } catch (err) {
-    print(JSON.stringify(['err', err.name + ': ' + err.message]));
+    print(JSON.stringify(['err', err.name + ': ' + err.message, err.stack]));
   }
 });
